//
//  UpnpDeviceInfo.m
//  uPnp2
//
//  Created by rk on 17/01/11.
//  Copyright 2011 Interchart. All rights reserved.
//

#import "UpnpDeviceInfo.h"


@implementation UpnpDeviceInfo

@synthesize deviceTypeSchema, friendlyName, manufacturer, modelName, UDN;
@synthesize services;

- (id) initWithXml:(NSData *)xml {
	if (!xml) return self;
	
	services = [[NSMutableArray alloc] init];
	NSXMLParser *parser = [[NSXMLParser alloc] initWithData:xml];
	[parser setDelegate:self];
	[parser parse];
	[parser release];
	return self;
}

#pragma mark -
#pragma mark NSXMLParserDelegate methods
- (void) parser:(NSXMLParser *)parser didStartElement:(NSString *)elementName
				namespaceURI:(NSString *)namespaceURI
				qualifiedName:(NSString *)qualifiedName
				attributes:(NSDictionary *)attributeDict {
	// deviceTypeSchema, friendlyName, manufacturer, modelName, UDN;
	if ([elementName isEqual:@"deviceType"]) {
		deviceTypeSchema = [[NSMutableString alloc] init];
		currentParserField = deviceTypeSchema;
	} else
	if ([elementName isEqual:@"friendlyName"]) {
		friendlyName = [[NSMutableString alloc] init];
		currentParserField = friendlyName;
	} else
	if ([elementName isEqual:@"manufacturer"]) {
		manufacturer = [[NSMutableString alloc] init];
		currentParserField = manufacturer;
	} else 
	if ([elementName isEqual:@"modelName"]) {
		modelName = [[NSMutableString alloc] init];
		currentParserField = modelName;
	} else 
	if ([elementName isEqual:@"UDN"]) {
		UDN = [[NSMutableString alloc] init];
		currentParserField = UDN;
	} else
	if ([elementName isEqual:@"service"]) {
		serviceBeingParsed = [[UpnpAvService alloc] init];
		servicesBuffer = [[NSMutableString alloc] init];
		currentParserField = servicesBuffer;
	}
}

- (void) parser:(NSXMLParser *)parser foundCharacters:(NSString *)string {
	[currentParserField appendString:string];
}

- (void) parser:(NSXMLParser *)parser didEndElement:(NSString *)elementName
				namespaceURI:(NSString *)namespaceURI
				qualifiedName:(NSString *)qualfilifiedName {
	if ([elementName isEqual:@"serviceType"]) {
		serviceBeingParsed.serviceType = servicesBuffer;
		[servicesBuffer setString:@""];
	}
	if ([elementName isEqual:@"serviceId"]) {
		serviceBeingParsed.serviceId = servicesBuffer;
		[servicesBuffer setString:@""];
	}
	if ([elementName isEqual:@"SCPDURL"]) {
		serviceBeingParsed.SCPDURL = servicesBuffer;
		[servicesBuffer setString:@""];
	}
	if ([elementName isEqual:@"controlURL"]) {
		serviceBeingParsed.controlURL = servicesBuffer;
		[servicesBuffer setString:@""];
	}
	if ([elementName isEqual:@"eventSubURL"]) {
		serviceBeingParsed.eventSubURL = servicesBuffer;
		[servicesBuffer setString:@""];
	}
	if ([elementName isEqual:@"service"]) {
		NSLog(@"%@: parser didEndElement '%@', servicesBuffer='%@'", 
			  self, 
			  elementName,
			  servicesBuffer);
		[servicesBuffer release];
		[services addObject:serviceBeingParsed];
		NSLog(@" services=%@, [services count] = %d", services, [services count]);
	}
	currentParserField = nil;
}
	


#pragma mark -

- (void) dealloc {
	[deviceTypeSchema release];
	[friendlyName release];
	[manufacturer release];
	[modelName release];
	[UDN release];
	for (id service in services) {
		[service release];
	}
	[services release];
	
	[super dealloc];
}

- (NSString *)description {
	return [NSString stringWithFormat:@"%@, %@", friendlyName, UDN];
}

@end
